@@ -63,6 +63,7 @@ inline static GtkWidget *capplet_lookup_widget(const CappletData *capp,
 
 void on_boolean_toggled(GtkToggleButton * button, CappletData *);
 
+/* Returns false if the event should be ignored */
 void on_radio_toggled(GtkToggleButton * button, CappletData *);
 
 void on_spin_button_changed(GtkSpinButton * button, CappletData *);
@@ -75,13 +76,13 @@ void on_combo_changed(GtkComboBox * combo, CappletData *);
 
 /**********************************************/
 
-/* As cappelt_set_boolean_toggle but sets the given state instead of
+/* As capplet_set_boolean_toggle but sets the given state instead of
  * looking up option */
 void capplet_set_toggle(CappletData *capp, const char *name, gboolean state);
 
 /* Convenience functions to lookup an option and set the widget with the same
- * name */
-void capplet_set_boolean_toggle(CappletData *capp,
+ * name. Returns the option's value */
+gboolean capplet_set_boolean_toggle(CappletData *capp,
     const char *name, gboolean dflt);
 
 void capplet_set_text_entry(CappletData *capp,
@@ -108,4 +109,4 @@ void capplet_dec_windows(void);
 
 #endif /* CAPPLET_H */
 
-/* vi:set sw=4 ts=4 noet cindent cino= */
+/* vi:set sw=4 ts=4 et cindent cino= */
