@@ -98,9 +98,10 @@ static void colourgui_set_all_palette_widgets(GtkBuilder *builder,
     g_return_if_fail(palette);
     for (n = 0; n < 16; ++n)
     {
-        char widget_name[20];
+        char widget_name[32];
 
-        sprintf(widget_name, "palette%d_%d", n / 8, n % 8);
+        snprintf(widget_name, sizeof(widget_name),
+			"palette%d_%d", n / 8, n % 8);
         colourgui_set_colour_widget(builder, widget_name, &palette[n], ignore);
     }
 }
@@ -108,12 +109,13 @@ static void colourgui_set_all_palette_widgets(GtkBuilder *builder,
 static void colourgui_shade_row(GtkBuilder *builder,
         int row, gboolean sensitive)
 {
-    char widget_name[20];
+    char widget_name[32];
     int column;
 
     for (column = 0; column < 8; ++column)
     {
-        sprintf(widget_name, "palette%d_%d", row, column);
+        snprintf(widget_name, sizeof(widget_name),
+			"palette%d_%d", row, column);
         gtk_widget_set_sensitive(GTK_WIDGET(gtk_builder_get_object(builder,
                 widget_name)), sensitive);
     }
@@ -126,7 +128,7 @@ static void colourgui_set_palette_shading(GtkBuilder *builder)
                 GTK_TOGGLE_BUTTON(gtk_builder_get_object(builder,
                         "use_custom_colours")));
     int row;
-    char widget_name[20];
+    char widget_name[32];
 
     if (use_custom)
     {
@@ -137,7 +139,8 @@ static void colourgui_set_palette_shading(GtkBuilder *builder)
     colourgui_shade_row(builder, 0, size_radio >= 0);
     for (row = 0; row < 2; ++row)
     {
-        sprintf(widget_name, "palette_size%d", row);
+        snprintf(widget_name, sizeof(widget_name),
+        	"palette_size%d", row);
         gtk_widget_set_sensitive(GTK_WIDGET(gtk_builder_get_object(builder,
                 widget_name)), use_custom);
     }
@@ -372,9 +375,10 @@ static const char *colourgui_name_colour(const GdkRGBA *colour)
 {
     static char colour_name[16];
 
-    sprintf(colour_name, "#%04hx%04hx%04hx", \
-        (guint16) (colour->red * 65535), \
-        (guint16) (colour->green * 65535), \
+	snprintf(colour_name, sizeof(colour_name),
+		"#%04hx%04hx%04hx",
+        (guint16) (colour->red * 65535),
+        (guint16) (colour->green * 65535),
         (guint16) (colour->blue * 65535));
     return colour_name;
 }
@@ -422,7 +426,7 @@ void on_color_set(GtkColorButton *button, ColourGUI * cg)
     GdkRGBA colour;
     const char *colour_name;
     const char *option_name = NULL;
-    char dyn_opt_nm[8];
+    char dyn_opt_nm[12];
     Options *opts = cg->capp.options;
 
     if (capplet_ignore_changes)
@@ -464,7 +468,7 @@ void on_color_set(GtkColorButton *button, ColourGUI * cg)
         int column = widget_name[9] - '0';
 
         colour_scheme_set_palette_entry(opts, row * 8 + column, colour_name);
-        sprintf(dyn_opt_nm, "%d", row * 8 + column);
+        snprintf(dyn_opt_nm, sizeof(dyn_opt_nm), "%d", row * 8 + column);
         option_name = dyn_opt_nm;
         if (row == 0 && gtk_toggle_button_get_active(
                 GTK_TOGGLE_BUTTON(gtk_builder_get_object(cg->capp.builder,
@@ -592,17 +596,18 @@ void on_use_custom_colours_toggled(GtkToggleButton *button, ColourGUI *cg)
         colourgui_set_palette_shading(cg->capp.builder);
         for (n = old_size; n < palette_size; ++n)
         {
-            char key[8];
+            char key[12];
             char *val;
 
-            sprintf(key, "%d", n);
+            snprintf(key, sizeof(key), "%d", n);
             val = options_lookup_string(cg->capp.options, key);
             if (!val)
             {
                 char widget_name[24];
                 const char *colour_name;
 
-                sprintf(widget_name, "palette%d_%d", n / 8, n % 8);
+                snprintf(widget_name, sizeof(widget_name) - 1,
+					"palette%d_%d", n / 8, n % 8);
                 colour_name = colourgui_read_colour_widget(cg, widget_name);
                 colour_scheme_set_palette_entry(cg->capp.options, n,
                         colour_name);
@@ -748,4 +753,4 @@ void colourgui_delete(ColourGUI * cg)
     configlet_unlock_colour_schemes();
 }
 
-/* vi:set sw=4 ts=4 noet cindent cino= */
+/* vi:set sw=4 ts=4 et cindent cino= */
