@@ -24,6 +24,7 @@
 #include "dlg.h"
 #include "dynopts.h"
 #include "getname.h"
+#include "globalopts.h"
 #include "optsdbus.h"
 #include "optsfile.h"
 #include "profilegui.h"
@@ -192,11 +193,18 @@ static void configlet_delete(ConfigletData *cg)
 static const char *family_name_to_opt_key(const char *family)
 {
     if (!strcmp(family, "Profiles"))
+    {
         return "profile";
+    }
     else if (!strcmp(family, "Colours"))
-        return "colour_scheme";
+    {
+        return global_options_system_theme_is_dark() ?
+            "colour_scheme_dark" : "colour_scheme_light";
+    }
     else if (!strcmp(family, "Shortcuts"))
+    {
         return "shortcut_scheme";
+    }
     return NULL;
 }
 
@@ -205,8 +213,18 @@ static char *configlet_get_configured_name(ConfigletList *cl)
     const char *optkey = family_name_to_opt_key(cl->family);
 
     g_return_val_if_fail(optkey, NULL);
+    const char *default_name;
+    if (strcmp(cl->family, "Colours"))
+    {
+        default_name = "Default";
+    } else {
+        default_name = global_options_system_theme_is_dark() ?
+            "Nocturne" : "GTK";
+        g_debug("Getting colour scheme for configlet: key %s, default %s",
+            optkey, default_name);
+    }
     return options_lookup_string_with_default(cl->cg->capp.options, optkey,
-            strcmp(cl->family, "Colours") ? "Default" : "GTK");
+            default_name);
 }
 
 static void configlet_list_build(ConfigletList *cl)
@@ -410,26 +428,6 @@ static gboolean get_selected_iter(ConfigletList *cl,
                 gtk_tree_view_get_selection(cl->tvwidget), pmodel, piter);
 }
 
-static int get_selected_index(ConfigletList *cl)
-{
-    /* FIXME: Is there a better way of doing this? */
-    GtkTreeIter iter;
-    GtkTreeModel *model = gtk_tree_view_get_model(cl->tvwidget);
-    GtkTreeSelection *selection;
-    int n = 0;
-
-    selection = gtk_tree_view_get_selection(cl->tvwidget);
-    if (!gtk_tree_model_get_iter_first(model, &iter))
-        return -1;
-    while (!gtk_tree_selection_iter_is_selected(selection, &iter))
-    {
-        if (!gtk_tree_model_iter_next(model, &iter))
-            return -1;
-        ++n;
-    }
-    return n;
-}
-
 static char *get_selected_name(ConfigletList *cl)
 {
     GtkTreeIter iter;
@@ -862,6 +860,43 @@ void on_shortcuts_rename_clicked(GtkButton *button, ConfigletData *cg)
     on_rename_clicked(&cg->shortcuts);
 }
 
+static void configlet_on_dark_pref_changed(G_GNUC_UNUSED gboolean prefer_dark,
+        ConfigletList *cl)
+{
+    char *name = configlet_get_configured_name(cl);
+    gtk_tree_model_foreach(GTK_TREE_MODEL(cl->list), update_radios, name);
+    g_debug("prefer-dark changed, selected scheme %s", name);
+    g_free(name);
+    global_options_apply_dark_theme();
+}
+
+void on_ui_theme_radio_toggled(GtkToggleButton *button, ConfigletData *cg)
+{
+    const char *name;
+
+    /* We'll get two events: one for the button going off and one for the
+     * button going on; we can ignore the former */
+    if (ignore_changes || !gtk_toggle_button_get_active(button))
+    {
+        return;
+    }
+    name = gtk_buildable_get_name(GTK_BUILDABLE(button));
+    if (name)
+    {
+        char *opt_name = g_strdup(name);
+        int l = strlen(name);
+        int n = atoi(name + l - 1);
+
+        g_return_if_fail(isdigit(name[l - 1]));
+        opt_name[l - 1] = 0;
+        capplet_set_int(global_options, opt_name, n);
+        g_free(opt_name);
+        configlet_on_dark_pref_changed(
+            global_options_system_theme_is_dark(),
+            &cg->colours);
+    }
+}
+
 /********************************************************************/
 
 static void configlet_add_button_to_size_group(ConfigletData *cg,
@@ -908,11 +943,17 @@ static void configlet_setup_family(ConfigletData *cg, ConfigletList *cl,
     {
         configlet_add_family_to_size_group(cg, family);
     }
+
+    if (!strcmp(family, "Colours"))
+    {
+        global_options_register_dark_theme_change_handler(
+            (GlobalOptionsDarkThemeChangeHandler)
+                configlet_on_dark_pref_changed, cl);
+    }
 }
 
 gboolean configlet_open()
 {
-
     if (configlet_data)
     {
         gtk_window_present(GTK_WINDOW(configlet_data->widget));
@@ -962,16 +1003,32 @@ gboolean configlet_open()
 
         capplet_set_radio(&cg->capp, "warn_close", 3);
         capplet_set_boolean_toggle(&cg->capp, "only_warn_running", FALSE);
-        if (g_object_class_find_property(
-                G_OBJECT_GET_CLASS(gtk_settings_get_default()),
-                "gtk-application-prefer-dark-theme"))
+
+        const char *hide_widget = NULL;
+        if (!global_options_has_gtk_dark_theme_setting())
         {
-            capplet_set_boolean_toggle(&cg->capp, "prefer_dark_theme", FALSE);
+            g_debug("GTK does not support dark theme");
+            hide_widget = "ui_theme_grid";
+        }
+        else if (!global_options_has_gnome_dark_theme_setting())
+        {
+            g_debug("GSettings does not support dark theme");
+            hide_widget = "prefer_dark_theme0";
+            int index = options_lookup_int_with_default(global_options,
+                    "prefer_dark_theme", 0);
+            if (index == 0) index = 2;
+            capplet_set_radio_by_index(cg->capp.builder,
+                "prefer_dark_theme", index);
         }
         else
         {
-            gtk_widget_hide(GTK_WIDGET(gtk_builder_get_object(cg->capp.builder,
-                    "prefer_dark_theme")));
+            g_debug("Dark theme fully supported");
+            capplet_set_radio(&cg->capp, "prefer_dark_theme", 0);
+        }
+        if (hide_widget)
+        {
+            GtkWidget *widget = capplet_lookup_widget(&cg->capp, hide_widget);
+            if (widget) gtk_widget_hide(widget);
         }
 
         capplet_inc_windows();
@@ -1039,4 +1096,4 @@ void configlet_unlock_shortcuts(void)
         set_sensitive_for_list(&configlet_data->shortcuts);
 }
 
-/* vi:set sw=4 ts=4 noet cindent cino= */
+/* vi:set sw=4 ts=4 et cindent cino= */
