@@ -1,8 +1,8 @@
 #ifndef DYNOPTS_H
 #define DYNOPTS_H
 /*
-    roxterm - GTK+ 2.0 terminal emulator with tabs
-    Copyright (C) 2004 Tony Houghton <h@realh.co.uk>
+    roxterm - VTE/GTK terminal emulator with tabs
+    Copyright (C) 2004-2015 Tony Houghton <h@realh.co.uk>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -63,7 +63,7 @@ inline static char **dynamic_options_list(DynamicOptions *dynopts)
     return dynamic_options_list_full(dynopts, FALSE);
 }
 
-/* As above but the list is sorted (except for Default) */
+/* As above but the list is sorted (but Default comes first) */
 inline static char **dynamic_options_list_sorted(DynamicOptions *dynopts)
 {
     return dynamic_options_list_full(dynopts, TRUE);
@@ -74,4 +74,4 @@ int dynamic_options_strcmp(const char *s1, const char *s2);
 
 #endif /* DYNOPTS_H */
 
-/* vi:set sw=4 ts=4 noet cindent cino= */
+/* vi:set sw=4 ts=4 et cindent cino= */
