@@ -1,8 +1,8 @@
 #ifndef OPTIONS_H
 #define OPTIONS_H
 /*
-    roxterm - GTK+ 2.0 terminal emulator with tabs
-    Copyright (C) 2004 Tony Houghton <h@realh.co.uk>
+    roxterm - VTE/GTK terminal emulator with tabs
+    Copyright (C) 2004-2015 Tony Houghton <h@realh.co.uk>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -31,15 +31,15 @@
 #include "optsfile.h"
 
 typedef struct {
-	GKeyFile *kf;
-	int ref;
-	gpointer user_data;
-	gboolean kf_dirty;
-	const char *group_name;		/* For GKeyFile */
-	char *name;					/* leafname for saving; includes "Profiles"
-								   or "Shortcuts" or whatever */
-	gboolean deleted;			/* Has been deleted by configlet while still
-								   in use */
+    GKeyFile *kf;
+    int ref;
+    gpointer user_data;
+    gboolean kf_dirty;
+    const char *group_name; /* For GKeyFile */
+    char *name;             /* leafname for saving; includes "Profiles"
+                               or "Shortcuts" or whatever */
+    gboolean deleted;       /* Has been deleted by configlet while still
+                               in use */
 } Options;
 
 
@@ -56,7 +56,7 @@ void options_reload_keyfile(Options *options);
 /* Options start off with one reference when opened; this adds a reference */
 inline static void options_ref(Options *options)
 {
-	++options->ref;
+    ++options->ref;
 }
 
 /* Usually use options_unref instead except in special cases */
@@ -66,21 +66,27 @@ void options_delete(Options *options);
 gboolean options_unref(Options * options);
 
 char *options_lookup_string_with_default(Options * options,
-	const char *key, const char *default_value);
+    const char *key, const char *default_value);
 
 inline static char *options_lookup_string(Options * options, const char *key)
 {
-	return options_lookup_string_with_default(options, key, NULL);
+    return options_lookup_string_with_default(options, key, NULL);
 }
 
 int options_lookup_int_with_default(Options * options, const char *key, int d);
 
 inline static int options_lookup_int(Options * options, const char *key)
 {
-	return options_lookup_int_with_default(options, key, -1);
+    return options_lookup_int_with_default(options, key, -1);
 }
 
-double options_lookup_double(Options * options, const char *key);
+double options_lookup_double_with_default(Options * options, const char *key,
+        double d);
+
+inline static double options_lookup_double(Options * options, const char *key)
+{
+    return options_lookup_double_with_default(options, key, 0.0);
+}
 
 void options_set_string(Options * options, const char *key, const char *value);
 
@@ -89,16 +95,16 @@ void options_set_int(Options * options, const char *key, int value);
 void options_set_double(Options * options, const char *key, double value);
 
 /* Associates some data with a set of options; useful eg for storing a set of
- * GdkColors along with palette options */
+ * GdkRGBAs along with palette options */
 inline static void options_associate_data(Options * options, gpointer user_data)
 {
-	options->user_data = user_data;
+    options->user_data = user_data;
 }
 
 /* Returns the data associated above */
 inline static gpointer options_get_data(Options * options)
 {
-	return options->user_data;
+    return options->user_data;
 }
 
 /* Returns the last path element of the name member */
@@ -108,4 +114,4 @@ void options_change_leafname(Options *options, const char *new_leaf);
 
 #endif /* OPTIONS_H */
 
-/* vi:set sw=4 ts=4 noet cindent cino= */
+/* vi:set sw=4 ts=4 et cindent cino= */
