@@ -1,6 +1,6 @@
 /*
     roxterm - VTE/GTK terminal emulator with tabs
-    Copyright (C) 2004-2011 Tony Houghton <h@realh.co.uk>
+    Copyright (C) 2004-2015 Tony Houghton <h@realh.co.uk>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -39,6 +39,14 @@ void rtdbus_whinge(DBusError * pderror, const char *s)
         dbus_error_free(pderror);
 }
 
+void rtdbus_warn(DBusError * pderror, const char *s)
+{
+    g_warning("%s: %s", s,
+        dbus_error_is_set(pderror) ? pderror->message : _("<unknown>"));
+    if (dbus_error_is_set(pderror))
+        dbus_error_free(pderror);
+}
+
 static void rtdbus_shutdown(void)
 {
     if (rtdbus_connection)
@@ -68,7 +76,7 @@ gboolean rtdbus_send_message_with_reply(DBusMessage *message)
     DBusError derror;
     DBusMessage *reply;
     gboolean result = TRUE;
-    RTDBUS_ARG_CONST char *reply_msg = NULL;
+    const char *reply_msg = NULL;
 
     dbus_error_init(&derror);
     reply = dbus_connection_send_with_reply_and_block(rtdbus_connection,
@@ -90,10 +98,6 @@ gboolean rtdbus_send_message_with_reply(DBusMessage *message)
         result = FALSE;
         g_warning("%s", reply_msg);
     }
-#if ROXTERM_DBUS_OLD_ARGS_SEMANTICS
-    if (reply_msg)
-        dbus_free(reply_msg);
-#endif
     UNREF_LOG(dbus_message_unref(reply));
     return result;
 }
@@ -112,15 +116,7 @@ gboolean rtdbus_start_service(const char *name, const char *object_path,
     flags = DBUS_NAME_FLAG_ALLOW_REPLACEMENT | DBUS_NAME_FLAG_DO_NOT_QUEUE;
     if (replace)
         flags |= DBUS_NAME_FLAG_REPLACE_EXISTING;
-    result =
-#if HAVE_DBUS_BUS_REQUEST_NAME
-        dbus_bus_request_name
-#elif HAVE_DBUS_BUS_ACQUIRE_SERVICE
-        dbus_bus_acquire_service
-#else
-#error "Don't know how to request D-BUS service name"
-#endif
-            (rtdbus_connection, name, flags, &derror);
+    result = dbus_bus_request_name(rtdbus_connection, name, flags, &derror);
     switch (result)
     {
         case -1:
@@ -172,25 +168,20 @@ gboolean rtdbus_init(void)
     return status = TRUE;
 }
 
-gboolean rtdbus_add_signal_rule_and_filter(
-        const char *path, const char *interface,
-        DBusHandleMessageFunction filter_fn)
+gboolean rtdbus_add_rule_and_filter(const char *match_rule,
+        DBusHandleMessageFunction filter_fn, void *user_data)
 {
     DBusError derror;
-    char *match_rule;
 
     dbus_error_init(&derror);
-    match_rule = g_strdup_printf(
-            "type='signal',path='%s',interface='%s'",
-            path, interface);
     dbus_bus_add_match(rtdbus_connection, match_rule, &derror);
     if (dbus_error_is_set(&derror))
     {
-        rtdbus_whinge(&derror, _("Unable to add D-BUS signal match rule"));
+        rtdbus_whinge(&derror, _("Unable to add D-BUS match rule"));
         return FALSE;
     }
     if (!dbus_connection_add_filter(rtdbus_connection,
-            filter_fn, NULL, NULL))
+            filter_fn, user_data, NULL))
     {
         rtdbus_whinge(&derror, _("Unable to install D-BUS message filter"));
         return FALSE;
@@ -198,6 +189,18 @@ gboolean rtdbus_add_signal_rule_and_filter(
     return TRUE;
 }
 
+gboolean rtdbus_add_signal_rule_and_filter(
+        const char *path, const char *interface,
+        DBusHandleMessageFunction filter_fn)
+{
+    char *match_rule = g_strdup_printf(
+            "type='signal',path='%s',interface='%s'",
+            path, interface);
+    gboolean result = rtdbus_add_rule_and_filter(match_rule, filter_fn, NULL);
+    g_free(match_rule);
+    return result;
+}
+
 DBusMessage *rtdbus_append_args(DBusMessage *message, int first_arg_type, ...)
 {
     va_list ap;
@@ -289,7 +292,7 @@ char **rtdbus_get_message_args_as_strings(DBusMessageIter *iter)
             != DBUS_TYPE_INVALID;
             dbus_message_iter_next(iter))
     {
-        RTDBUS_ARG_CONST char *arg;
+        const char *arg;
 
         if (argtype != DBUS_TYPE_STRING)
         {
@@ -299,13 +302,7 @@ char **rtdbus_get_message_args_as_strings(DBusMessageIter *iter)
         }
         if (argc + 1 >= len)
             argv = g_renew(char *, argv, len = len ? len * 2 : 2);
-#if HAVE_DBUS_MESSAGE_ITER_GET_BASIC
         dbus_message_iter_get_basic(iter, &arg);
-#elif HAVE_DBUS_MESSAGE_ITER_GET_STRING
-        arg = dbus_message_iter_get_string(iter);
-#else
-#error "Don't know how to read D-BUS message arguments from iterator"
-#endif
         /* Check in case arg may be NULL string (probably not) */
         if (!arg)
         {
@@ -316,9 +313,6 @@ char **rtdbus_get_message_args_as_strings(DBusMessageIter *iter)
             /* Always g_strdup in case dbus' memory management was incompatible
              * with glib's */
             argv[argc] = g_strdup(arg);
-#if ROXTERM_DBUS_OLD_ARGS_SEMANTICS
-            dbus_free(arg);
-#endif
         }
         argv[++argc] = NULL;
     }
@@ -347,4 +341,4 @@ char **rtdbus_get_message_arg_string_array(DBusMessageIter *iter)
     return rtdbus_get_message_args_as_strings(&sub_iter);
 }
 
-/* vi:set sw=4 ts=4 noet cindent cino= */
+/* vi:set sw=4 ts=4 et cindent cino= */
