@@ -2,7 +2,7 @@
 #define RTDBUS_H
 /*
     roxterm - VTE/GTK terminal emulator with tabs
-    Copyright (C) 2004-2011 Tony Houghton <h@realh.co.uk>
+    Copyright (C) 2004-2015 Tony Houghton <h@realh.co.uk>
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,17 +26,8 @@
 #include "defns.h"
 #endif
 
-#define DBUS_API_SUBJECT_TO_CHANGE
 #include <dbus/dbus-glib-lowlevel.h>
 
-#if ROXTERM_DBUS_OLD_ARGS_SEMANTICS
-#define RTDBUS_ARG(a) a
-#define RTDBUS_ARG_CONST
-#else
-#define RTDBUS_ARG(a) &(a)
-#define RTDBUS_ARG_CONST const
-#endif
-
 /* These are just stubs; they should have a specific suffix appended */
 #define RTDBUS_NAME "net.sf.roxterm"
 #define RTDBUS_OBJECT_PATH "/net/sf/roxterm"
@@ -48,9 +39,13 @@ extern DBusGConnection *rtdbus_g_connection;
 
 extern gboolean rtdbus_ok;
 
-/* Report a D-BUS error, prepending message 's', then free the error data */
+/* Report a D-BUS error in a dialog, prepending message 's',
+ * then free the error data */
 void rtdbus_whinge(DBusError *pderror, const char *s);
 
+/* As above but print it on the console with g_warning */
+void rtdbus_warn(DBusError *pderror, const char *s);
+
 /* Unrefs message after sending */
 gboolean rtdbus_send_message(DBusMessage *message);
 
@@ -64,20 +59,24 @@ gboolean rtdbus_start_service(const char *name, const char *object_path,
 /* Call before any other D-BUS functions. May be called more than once */
 gboolean rtdbus_init(void);
 
-/* Adds a match rule and signal filter */
+/* Adds a match rule and filter */
+gboolean rtdbus_add_rule_and_filter(const char *match_rule,
+        DBusHandleMessageFunction filter_fn, void *user_data);
+
+/* Constructs a match rule for the given signal and adds a filter for it */
 gboolean rtdbus_add_signal_rule_and_filter(
 		const char *path, const char *interface,
 		DBusHandleMessageFunction);
 
 /* Creates a signal message with the given arguments passed as pairs of
- * DBUS_TYPE_*, RTDBUS_ARG(*) terminated by DBUS_TYPE_INVALID */
+ * DBUS_TYPE_*, &(*) terminated by DBUS_TYPE_INVALID */
 DBusMessage *rtdbus_signal_new(const char *object_path, const char *interface,
 		const char *signal_name, int first_arg_type, ...);
 
 /* As above but creates a method call */
-DBusMessage *rtdbus_method_new(
-		const char *bus_name, const char *object_path, const char *interface,
-		const char *method_name, int first_arg_type, ...);
+DBusMessage *rtdbus_method_new(const char *bus_name, const char *object_path,
+        const char *interface, const char *method_name,
+        int first_arg_type, ...);
 
 /* Appends args (see above) to message and returns the modified message. On
  * failure (unlikely) the message is freed, an error is printed and NULL is
@@ -101,4 +100,4 @@ char **rtdbus_get_message_arg_string_array(DBusMessageIter *iter);
 
 #endif /* RTDBUS_H */
 
-/* vi:set sw=4 ts=4 noet cindent cino= */
+/* vi:set sw=4 ts=4 et cindent cino= */
